API Specification
-----------------

This page covers the API specification for the following classes and utility
functions:

* :class:`binarytree.Node`
* :func:`binarytree.build`
* :func:`binarytree.build2`
* :func:`binarytree.tree`
* :func:`binarytree.bst`
* :func:`binarytree.heap`
* :func:`binarytree.get_parent`

Class: binarytree.Node
======================

.. autoclass:: binarytree.Node
    :members:
    :special-members:
    :private-members:
    :exclude-members: __weakref__, __repr__, __setattr__, __init__

Function: binarytree.build
==========================

.. autofunction:: binarytree.build

Function: binarytree.build2
===========================

.. autofunction:: binarytree.build2

Function: binarytree.tree
=========================

.. autofunction:: binarytree.tree

Function: binarytree.bst
========================

.. autofunction:: binarytree.bst

Function: binarytree.heap
=========================

.. autofunction:: binarytree.heap

Function: binarytree.get_index
===============================

.. autofunction:: binarytree.get_index

Function: binarytree.get_parent
===============================

.. autofunction:: binarytree.get_parent
